@@ -636,10 +636,21 @@ Orbited.CometSession = function() {
 ;;;     self.logger.debug('setting sending=true');
         var numSent = sendQueue.length
         sessionUrl.setQsParameter('ack', lastPacketId)
-//        xhr = createXHR();
+        var tdata = encodePackets(sendQueue)
+;;;     self.logger.debug('post', retries, tdata);
+        if (Orbited.settings.enableFFPrivleges) {
+            try { 
+                netscape.security.PrivilegeManager.enablePrivilege('UniversalBrowserRead'); 
+            } catch (ex) { } 
+        }        
+        xhr.open('POST', sessionUrl.render(), true)
+        // NB: its awkard, but for reusing the XHR object in IE (7 at least),
+        //     we can only reset the onreadystatechange *after* we call open;
+        //     if we don't do this, the XHR will stop sending data.
+        // See "Reusing XMLHttpRequest Object in IE"
+        //     at http://keelypavan.blogspot.com/2006/03/reusing-xmlhttprequest-object-in-ie.html
         xhr.onreadystatechange = function() {
             switch(xhr.readyState) {
-                
                 case 4:
                     if (xhr.status == 200) {
                         resetTimeout();
@@ -657,16 +668,7 @@ Orbited.CometSession = function() {
                     }
             }
         }
-        var tdata = encodePackets(sendQueue)
-;;;     self.logger.debug('post', retries, tdata);
-        if (Orbited.settings.enableFFPrivleges) {
-            try { 
-                netscape.security.PrivilegeManager.enablePrivilege('UniversalBrowserRead'); 
-            } catch (ex) { } 
-        }        
-        xhr.open('POST', sessionUrl.render(), true)
         xhr.send(tdata)
-
     }
     
     var doClose = function(code) {
@@ -786,10 +788,10 @@ Orbited.TCPSocket = function() {
     }
 
     var process = function() {
-        var result = Orbited.utf8.decode(buffer)
-        var data = result[0]
-        var i = result[1]
-        buffer = buffer.slice(i)
+        var result = Orbited.utf8.decode(buffer);
+        var data = result[0];
+        var i = result[1];
+        buffer = buffer.slice(i);
         if (data.length > 0) {
             window.setTimeout(function() { self.onread(data) }, 0);
         }
@@ -800,14 +802,12 @@ Orbited.TCPSocket = function() {
             case self.READY_STATE_OPEN:
 ;;;             self.logger.debug('READ: ', data)
                 var data = data;
-                if (self.binary) {
+                if (binary) {
                     window.setTimeout(function() { self.onread(data) }, 0);
                 }
                 else {
 ;;;                 self.logger.debug('start buffer size:', buffer.length)
                     buffer += data;
-//                    data.splice(0,0,buffer.length, 0)
-//                    buffer.splice.apply(buffer, data)
                     process()
 ;;;                 self.logger.debug('end buffer size:', buffer.length)
                 }
